.. _config:

========================================
Config subpackage :mod:`melusine.config`
========================================

TODO : ADD DESCRIPTION OF THE SUBPACKAGE

------------------
List of submodules
------------------
.. contents::
   :local:


Config :mod:`melusine.config.config`
------------------------------------

.. automodule:: melusine.config.config
   :members:
   :undoc-members:
   :show-inheritance:
